@@ -49,7 +49,7 @@ ci_vars <- c(
   "WERCKER_GIT_REPOSITORY" = NA,
   "WERCKER_MAIN_PIPELINE_STARTED" = NA)
 
-cov <- package_coverage("TestS4")
+cov <- package_coverage(test_path("TestS4"))
 
 test_that("it generates a properly formatted json file", {
 
@@ -72,6 +72,21 @@ test_that("it generates a properly formatted json file", {
       ))
 })
 
+test_that("it adds a flags argument to the query if specified", {
+
+  withr::with_envvar(ci_vars,
+    with_mock(
+      `httr::POST` = function(...) list(...),
+      `httr::content` = identity,
+      `covr:::local_branch` = function() "master",
+      `covr:::current_commit` = function() "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3",
+
+      res <- codecov(coverage = cov, flags = "R"),
+      expect_equal(res$query$flags, "R")
+    )
+  )
+})
+
 test_that("it works with local repos", {
   withr::with_envvar(ci_vars, {
 
@@ -124,6 +139,24 @@ test_that("it adds the token to the query if available", {
       )
     )
   })
+test_that("it looks for token in a .yml file", {
+  withr::with_envvar(c(ci_vars),
+    with_mock(
+      `httr::POST` = function(...) list(...),
+      `httr::content` = identity,
+      `covr:::local_branch` = function() "master",
+      `covr:::current_commit` = function() "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3",
+
+      res <- codecov(coverage = cov),
+
+      expect_match(res$url, "/upload/v2"), # nolint
+      expect_match(res$query$branch, "master"),
+      expect_match(res$query$commit, "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3"),
+      expect_match(res$query$token, "codecov_token_from_yaml")
+    )
+  )
+  })
+
 test_that("it works with jenkins", {
   withr::with_envvar(c(
       ci_vars,
